[clang] d4a0154 - [llvm-project] Fix typo "seperate" (#95373)
via cfe-commits
cfe-commits at lists.llvm.org
Thu Jun 13 12:20:38 PDT 2024
Author: Jay Foad
Date: 2024-06-13T20:20:27+01:00
New Revision: d4a0154902fb9b0611ed857134b26a64a1d5ad1e
URL: https://github.com/llvm/llvm-project/commit/d4a0154902fb9b0611ed857134b26a64a1d5ad1e
DIFF: https://github.com/llvm/llvm-project/commit/d4a0154902fb9b0611ed857134b26a64a1d5ad1e.diff
LOG: [llvm-project] Fix typo "seperate" (#95373)
Added:
Modified:
clang-tools-extra/clangd/TidyProvider.cpp
clang/include/clang/Frontend/FrontendOptions.h
clang/include/clang/InstallAPI/DylibVerifier.h
clang/lib/InstallAPI/Visitor.cpp
clang/lib/Serialization/ASTWriterStmt.cpp
compiler-rt/test/dfsan/custom.cpp
compiler-rt/test/orc/TestCases/Linux/ppc64/trivial-tls-pwr10.test
flang/examples/FlangOmpReport/yaml_summarizer.py
flang/lib/Semantics/check-omp-structure.cpp
flang/test/Driver/mllvm_vs_mmlir.f90
libc/src/__support/FPUtil/x86_64/FEnvImpl.h
libc/src/stdio/printf_core/float_hex_converter.h
libc/test/src/__support/str_to_float_comparison_test.cpp
lld/test/wasm/data-segments.ll
lldb/include/lldb/Expression/DWARFExpressionList.h
lldb/include/lldb/Target/MemoryTagManager.h
lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp
lldb/test/API/CMakeLists.txt
lldb/test/API/tools/lldb-server/memory-tagging/TestGdbRemoteMemoryTagging.py
lldb/test/Shell/SymbolFile/DWARF/x86/DW_AT_data_bit_offset-DW_OP_stack_value.s
llvm/include/llvm/CodeGen/LiveRegUnits.h
llvm/include/llvm/CodeGen/MIRFormatter.h
llvm/include/llvm/MC/MCAsmInfo.h
llvm/include/llvm/Support/raw_socket_stream.h
llvm/lib/CodeGen/AsmPrinter/CodeViewDebug.h
llvm/lib/CodeGen/AssignmentTrackingAnalysis.cpp
llvm/lib/CodeGen/SelectionDAG/SelectionDAGBuilder.cpp
llvm/lib/FileCheck/FileCheck.cpp
llvm/lib/IR/DebugInfo.cpp
llvm/lib/MC/MCPseudoProbe.cpp
llvm/lib/Support/VirtualFileSystem.cpp
llvm/lib/Support/raw_socket_stream.cpp
llvm/lib/Target/ARM/ARMISelLowering.cpp
llvm/lib/Target/RISCV/RISCVMachineFunctionInfo.h
llvm/lib/TargetParser/RISCVISAInfo.cpp
llvm/lib/TextAPI/Utils.cpp
llvm/lib/Transforms/IPO/Attributor.cpp
llvm/lib/Transforms/IPO/SampleProfileProbe.cpp
llvm/lib/Transforms/Scalar/RewriteStatepointsForGC.cpp
llvm/lib/Transforms/Utils/LoopUnrollRuntime.cpp
llvm/test/CodeGen/X86/AMX/amx-greedy-ra.ll
llvm/test/CodeGen/X86/apx/shift-eflags.ll
llvm/test/CodeGen/X86/merge-consecutive-stores-nt.ll
llvm/test/CodeGen/X86/shift-eflags.ll
llvm/test/Transforms/InstSimplify/constant-fold-fp-denormal.ll
llvm/test/Transforms/LoopVectorize/LoongArch/defaults.ll
llvm/test/Transforms/LoopVectorize/RISCV/defaults.ll
llvm/test/Transforms/SeparateConstOffsetFromGEP/split-gep-or-as-add.ll
llvm/test/Verifier/alloc-size-failedparse.ll
llvm/test/tools/llvm-ar/windows-path.test
llvm/test/tools/llvm-objcopy/ELF/mirror-permissions-win.test
llvm/tools/llvm-cov/CodeCoverage.cpp
llvm/tools/llvm-profgen/PerfReader.cpp
llvm/unittests/Support/Path.cpp
mlir/include/mlir/Analysis/Presburger/IntegerRelation.h
mlir/include/mlir/Analysis/Presburger/PresburgerSpace.h
mlir/include/mlir/Dialect/OpenMP/OpenMPInterfaces.h
mlir/lib/Analysis/Presburger/PresburgerSpace.cpp
mlir/lib/Conversion/GPUCommon/GPUOpsLowering.h
mlir/lib/Dialect/LLVMIR/IR/BasicPtxBuilderInterface.cpp
mlir/lib/Target/LLVMIR/Dialect/OpenMP/OpenMPToLLVMIRTranslation.cpp
mlir/test/Integration/Dialect/SparseTensor/CPU/sparse_reduce_custom_prod.mlir
mlir/test/Target/LLVMIR/omptarget-constant-alloca-raise.mlir
openmp/tools/Modules/FindOpenMPTarget.cmake
Removed:
################################################################################
diff --git a/clang/include/clang/Frontend/FrontendOptions.h b/clang/include/clang/Frontend/FrontendOptions.h
index bd4981ca0ac08..ebb8e9e59c6b6 100644
--- a/clang/include/clang/Frontend/FrontendOptions.h
+++ b/clang/include/clang/Frontend/FrontendOptions.h
@@ -520,7 +520,7 @@ class FrontendOptions {
std::string ProductName;
// Currently this is only used as part of the `-extract-api` action.
- // A comma seperated list of files providing a list of APIs to
+ // A comma separated list of files providing a list of APIs to
// ignore when extracting documentation.
std::vector<std::string> ExtractAPIIgnoresFileList;
diff --git a/clang/include/clang/InstallAPI/DylibVerifier.h b/clang/include/clang/InstallAPI/DylibVerifier.h
index ae0428abbb9c7..333f0cff077fd 100644
--- a/clang/include/clang/InstallAPI/DylibVerifier.h
+++ b/clang/include/clang/InstallAPI/DylibVerifier.h
@@ -135,7 +135,7 @@ class DylibVerifier : llvm::MachO::RecordVisitor {
// Check if an internal declaration in zippered library has an
// external declaration for a
diff erent platform. This results
- // in the symbol being in a "seperate" platform slice.
+ // in the symbol being in a "separate" platform slice.
bool shouldIgnoreInternalZipperedSymbol(const Record *R,
const SymbolContext &SymCtx) const;
diff --git a/clang/lib/InstallAPI/Visitor.cpp b/clang/lib/InstallAPI/Visitor.cpp
index cf3aaa4c6ec93..367ae53b208b6 100644
--- a/clang/lib/InstallAPI/Visitor.cpp
+++ b/clang/lib/InstallAPI/Visitor.cpp
@@ -218,7 +218,7 @@ bool InstallAPIVisitor::VisitVarDecl(const VarDecl *D) {
if (isa<ParmVarDecl>(D))
return true;
- // Skip variables in records. They are handled seperately for C++.
+ // Skip variables in records. They are handled separately for C++.
if (D->getDeclContext()->isRecord())
return true;
diff --git a/clang/lib/Serialization/ASTWriterStmt.cpp b/clang/lib/Serialization/ASTWriterStmt.cpp
index 1a98e30e0f89f..1ba6d5501fd10 100644
--- a/clang/lib/Serialization/ASTWriterStmt.cpp
+++ b/clang/lib/Serialization/ASTWriterStmt.cpp
@@ -37,7 +37,7 @@ namespace clang {
unsigned AbbrevToUse;
/// A helper that can help us to write a packed bit across function
- /// calls. For example, we may write seperate bits in seperate functions:
+ /// calls. For example, we may write separate bits in separate functions:
///
/// void VisitA(A* a) {
/// Record.push_back(a->isSomething());
diff --git a/compiler-rt/test/dfsan/custom.cpp b/compiler-rt/test/dfsan/custom.cpp
index cede0d64dbcf2..54bb17cb4a035 100644
--- a/compiler-rt/test/dfsan/custom.cpp
+++ b/compiler-rt/test/dfsan/custom.cpp
@@ -2280,7 +2280,7 @@ void test_sscanf() {
// %n, %s, %d, %f, and %% already tested
}
-// Tested by a seperate source file. This empty function is here to appease the
+// Tested by a separate source file. This empty function is here to appease the
// check-wrappers script.
void test_fork() {}
diff --git a/compiler-rt/test/orc/TestCases/Linux/ppc64/trivial-tls-pwr10.test b/compiler-rt/test/orc/TestCases/Linux/ppc64/trivial-tls-pwr10.test
index 93561b1645c33..a393a009d2f5a 100644
--- a/compiler-rt/test/orc/TestCases/Linux/ppc64/trivial-tls-pwr10.test
+++ b/compiler-rt/test/orc/TestCases/Linux/ppc64/trivial-tls-pwr10.test
@@ -2,7 +2,7 @@
// RUN: %clangxx -fPIC -c -o %t/main.o %S/Inputs/trivial-tls-main.cpp
// RUN: %clangxx -fPIC -c -o %t/pwr10.o %S/Inputs/trivial-tls-pwr10.cpp
// RUN: %llvm_jitlink %t/main.o %t/pwr10.o
-// FIXME: We seperate pwr10 code from main object file due to currrent
+// FIXME: We separate pwr10 code from main object file due to currrent
// implementation only supports one PLT stub for the same symbol.
// For example, `bl __tls_get_addr` in one object file has only one PLT stub,
// however we need another
diff erent PLT stub for `bl __tls_get_addr at notoc`
diff --git a/flang/examples/FlangOmpReport/yaml_summarizer.py b/flang/examples/FlangOmpReport/yaml_summarizer.py
index 5726ff8da77f5..1e522c00aab8d 100644
--- a/flang/examples/FlangOmpReport/yaml_summarizer.py
+++ b/flang/examples/FlangOmpReport/yaml_summarizer.py
@@ -21,7 +21,7 @@
Parameters:
-d --directory Specify which directory to scan. Multiple directories can be searched by
- providing a semicolon seperated list of directories.
+ providing a semicolon separated list of directories.
-l --log Combine all yaml files into one log (instead of generating a summary)
diff --git a/flang/lib/Semantics/check-omp-structure.cpp b/flang/lib/Semantics/check-omp-structure.cpp
index 2d3ccd1c0c195..e5baddf599402 100644
--- a/flang/lib/Semantics/check-omp-structure.cpp
+++ b/flang/lib/Semantics/check-omp-structure.cpp
@@ -2781,7 +2781,7 @@ void OmpStructureChecker::CheckIsLoopIvPartOfClause(
}
}
}
-// Following clauses have a seperate node in parse-tree.h.
+// Following clauses have a separate node in parse-tree.h.
// Atomic-clause
CHECK_SIMPLE_PARSER_CLAUSE(OmpAtomicRead, OMPC_read)
CHECK_SIMPLE_PARSER_CLAUSE(OmpAtomicWrite, OMPC_write)
@@ -2887,18 +2887,18 @@ void OmpStructureChecker::CheckAllowedMapTypes(
const parser::OmpMapType::Type &type,
const std::list<parser::OmpMapType::Type> &allowedMapTypeList) {
if (!llvm::is_contained(allowedMapTypeList, type)) {
- std::string commaSeperatedMapTypes;
+ std::string commaSeparatedMapTypes;
llvm::interleave(
allowedMapTypeList.begin(), allowedMapTypeList.end(),
[&](const parser::OmpMapType::Type &mapType) {
- commaSeperatedMapTypes.append(parser::ToUpperCaseLetters(
+ commaSeparatedMapTypes.append(parser::ToUpperCaseLetters(
parser::OmpMapType::EnumToString(mapType)));
},
- [&] { commaSeperatedMapTypes.append(", "); });
+ [&] { commaSeparatedMapTypes.append(", "); });
context_.Say(GetContext().clauseSource,
"Only the %s map types are permitted "
"for MAP clauses on the %s directive"_err_en_US,
- commaSeperatedMapTypes, ContextDirectiveAsFortran());
+ commaSeparatedMapTypes, ContextDirectiveAsFortran());
}
}
diff --git a/flang/test/Driver/mllvm_vs_mmlir.f90 b/flang/test/Driver/mllvm_vs_mmlir.f90
index 99c3418dc6a1f..074843fe99368 100644
--- a/flang/test/Driver/mllvm_vs_mmlir.f90
+++ b/flang/test/Driver/mllvm_vs_mmlir.f90
@@ -1,6 +1,6 @@
! Verify that `-mllvm` options are forwarded to LLVM and `-mmlir` to MLIR.
-! In practice, '-mmlir --help' is a super-set of '-mllvm --help' and that limits what we can test here. With a better seperation of
+! In practice, '-mmlir --help' is a super-set of '-mllvm --help' and that limits what we can test here. With a better separation of
! LLVM, MLIR and Flang global options, we should be able to write a stricter test.
! RUN: %flang_fc1 -mmlir --help | FileCheck %s --check-prefix=MLIR
diff --git a/libc/src/__support/FPUtil/x86_64/FEnvImpl.h b/libc/src/__support/FPUtil/x86_64/FEnvImpl.h
index a157b81aaaf32..2aa69565efc58 100644
--- a/libc/src/__support/FPUtil/x86_64/FEnvImpl.h
+++ b/libc/src/__support/FPUtil/x86_64/FEnvImpl.h
@@ -248,7 +248,7 @@ LIBC_INLINE int raise_except(int excepts) {
// of the "Intel 64 and IA-32 Architectures Software Developer's
// Manual, Vol 1".
- // FPU status word is read for each exception seperately as the
+ // FPU status word is read for each exception separately as the
// exception handler can potentially write to it (typically to clear
// the corresponding exception flag). By reading it separately, we
// ensure that the writes by the exception handler are maintained
diff --git a/libc/src/stdio/printf_core/float_hex_converter.h b/libc/src/stdio/printf_core/float_hex_converter.h
index 68a4ba6209d09..8fac36df3d1e2 100644
--- a/libc/src/stdio/printf_core/float_hex_converter.h
+++ b/libc/src/stdio/printf_core/float_hex_converter.h
@@ -199,13 +199,13 @@ LIBC_INLINE int convert_float_hex_exp(Writer *writer,
constexpr cpp::string_view HEXADECIMAL_POINT(".");
// This is for the letter 'p' before the exponent.
- const char exp_seperator = a + ('p' - 'a');
- constexpr int EXP_SEPERATOR_LEN = 1;
+ const char exp_separator = a + ('p' - 'a');
+ constexpr int EXP_SEPARATOR_LEN = 1;
padding = static_cast<int>(to_conv.min_width - (sign_char > 0 ? 1 : 0) -
PREFIX_LEN - mant_digits - trailing_zeroes -
static_cast<int>(has_hexadecimal_point) -
- EXP_SEPERATOR_LEN - (EXP_LEN - exp_cur));
+ EXP_SEPARATOR_LEN - (EXP_LEN - exp_cur));
if (padding < 0)
padding = 0;
@@ -223,7 +223,7 @@ LIBC_INLINE int convert_float_hex_exp(Writer *writer,
RET_IF_RESULT_NEGATIVE(writer->write({mant_buffer + 1, mant_digits - 1}));
if (trailing_zeroes > 0)
RET_IF_RESULT_NEGATIVE(writer->write('0', trailing_zeroes));
- RET_IF_RESULT_NEGATIVE(writer->write(exp_seperator));
+ RET_IF_RESULT_NEGATIVE(writer->write(exp_separator));
RET_IF_RESULT_NEGATIVE(
writer->write({exp_buffer + exp_cur, EXP_LEN - exp_cur}));
if (padding > 0)
@@ -247,7 +247,7 @@ LIBC_INLINE int convert_float_hex_exp(Writer *writer,
RET_IF_RESULT_NEGATIVE(writer->write({mant_buffer + 1, mant_digits - 1}));
if (trailing_zeroes > 0)
RET_IF_RESULT_NEGATIVE(writer->write('0', trailing_zeroes));
- RET_IF_RESULT_NEGATIVE(writer->write(exp_seperator));
+ RET_IF_RESULT_NEGATIVE(writer->write(exp_separator));
RET_IF_RESULT_NEGATIVE(
writer->write({exp_buffer + exp_cur, EXP_LEN - exp_cur}));
}
diff --git a/libc/test/src/__support/str_to_float_comparison_test.cpp b/libc/test/src/__support/str_to_float_comparison_test.cpp
index 19f3f869f3c4c..7641c594c3d3b 100644
--- a/libc/test/src/__support/str_to_float_comparison_test.cpp
+++ b/libc/test/src/__support/str_to_float_comparison_test.cpp
@@ -143,7 +143,7 @@ int main(int argc, char *argv[]) {
int fails = 0;
// Bit
diff s are cases where the expected result and actual result only
diff er
- // by +/- the least significant bit. They are tracked seperately from larger
+ // by +/- the least significant bit. They are tracked separately from larger
// failures since a bit
diff is most likely the result of a rounding error, and
// splitting them off makes them easier to track down.
int bit
diff s = 0;
diff --git a/lld/test/wasm/data-segments.ll b/lld/test/wasm/data-segments.ll
index 7ff949794d8e9..9354e6c8e4d2b 100644
--- a/lld/test/wasm/data-segments.ll
+++ b/lld/test/wasm/data-segments.ll
@@ -161,7 +161,7 @@
; DIS-EMPTY:
; DIS-NEXT: end
-; In PIC mode __wasm_apply_data_relocs is export seperatly to __wasm_call_ctors
+; In PIC mode __wasm_apply_data_relocs is export separatly to __wasm_call_ctors
; PIC-DIS: <__wasm_apply_data_relocs>:
; PIC-DIS-EMPTY:
diff --git a/lldb/include/lldb/Expression/DWARFExpressionList.h b/lldb/include/lldb/Expression/DWARFExpressionList.h
index f711a1cbe9bbd..664c2603770f6 100644
--- a/lldb/include/lldb/Expression/DWARFExpressionList.h
+++ b/lldb/include/lldb/Expression/DWARFExpressionList.h
@@ -92,7 +92,7 @@ class DWARFExpressionList {
lldb::addr_t func_load_addr, lldb::addr_t file_addr,
ABI *abi) const;
- /// Dump all locaitons with each seperated by new line.
+ /// Dump all locaitons with each separated by new line.
void GetDescription(Stream *s, lldb::DescriptionLevel level, ABI *abi) const;
/// Search for a load address in the dwarf location list
diff --git a/lldb/include/lldb/Target/MemoryTagManager.h b/lldb/include/lldb/Target/MemoryTagManager.h
index b082224c38edb..6bd4180fff703 100644
--- a/lldb/include/lldb/Target/MemoryTagManager.h
+++ b/lldb/include/lldb/Target/MemoryTagManager.h
@@ -103,7 +103,7 @@ class MemoryTagManager {
// transport.
virtual size_t GetTagSizeInBytes() const = 0;
- // Unpack tags from their stored format (e.g. gdb qMemTags data) into seperate
+ // Unpack tags from their stored format (e.g. gdb qMemTags data) into separate
// tags.
//
// Checks that each tag is within the expected value range and if granules is
diff --git a/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp b/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp
index 9b5f7aef1efe5..5397e90022f39 100644
--- a/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp
+++ b/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp
@@ -388,7 +388,7 @@ NativeRegisterContextLinux_arm64::ReadRegister(const RegisterInfo *reg_info,
return error;
}
- // ZA is part of the SME set but uses a seperate member buffer for
+ // ZA is part of the SME set but uses a separate member buffer for
// storage. Therefore its effective byte offset is always 0 even if it
// isn't 0 within the SME register set.
src = (uint8_t *)GetZABuffer() + GetZAHeaderSize();
diff --git a/lldb/test/API/CMakeLists.txt b/lldb/test/API/CMakeLists.txt
index 856beb894208c..27f285230cafa 100644
--- a/lldb/test/API/CMakeLists.txt
+++ b/lldb/test/API/CMakeLists.txt
@@ -36,7 +36,7 @@ set(LLDB_TEST_ARCH
# Users can override LLDB_TEST_USER_ARGS to specify arbitrary arguments to pass to the script
set(LLDB_TEST_USER_ARGS
""
- CACHE STRING "Specify additional arguments to pass to test runner. Seperate \
+ CACHE STRING "Specify additional arguments to pass to test runner. Separate \
items with \";\". For example: '-C;gcc;-C;clang;-A;i386;-A;x86_64'")
set(LLDB_TEST_COMMON_ARGS_VAR
diff --git a/lldb/test/API/tools/lldb-server/memory-tagging/TestGdbRemoteMemoryTagging.py b/lldb/test/API/tools/lldb-server/memory-tagging/TestGdbRemoteMemoryTagging.py
index 6ddd264057c3c..87507583724e6 100644
--- a/lldb/test/API/tools/lldb-server/memory-tagging/TestGdbRemoteMemoryTagging.py
+++ b/lldb/test/API/tools/lldb-server/memory-tagging/TestGdbRemoteMemoryTagging.py
@@ -170,7 +170,7 @@ def test_tag_write_QMemTags_packets(self):
self.check_tag_write("{:x},20".format(buf_address), "E03")
# Missing data
self.check_tag_write("{:x},20:1".format(buf_address), "E03")
- # Zero length write must still include seperator after type
+ # Zero length write must still include separator after type
self.check_tag_write("{:x},0:1".format(buf_address), "E03")
# Empty address
self.check_tag_write(",10:1:01", "E03")
diff --git a/lldb/test/Shell/SymbolFile/DWARF/x86/DW_AT_data_bit_offset-DW_OP_stack_value.s b/lldb/test/Shell/SymbolFile/DWARF/x86/DW_AT_data_bit_offset-DW_OP_stack_value.s
index 074da09bc61ee..f82dd19466e63 100644
--- a/lldb/test/Shell/SymbolFile/DWARF/x86/DW_AT_data_bit_offset-DW_OP_stack_value.s
+++ b/lldb/test/Shell/SymbolFile/DWARF/x86/DW_AT_data_bit_offset-DW_OP_stack_value.s
@@ -51,7 +51,7 @@
#
# DW_AT_location (DW_OP_constu 0x64a40101, DW_OP_stack_value)
#
-# to work-around a seperate bug.
+# to work-around a separate bug.
.zerofill __DATA,__bss,__type_anchor,4,2 ## @_type_anchor
.zerofill __DATA,__bss,_ug.0,1,2 ## @ug.0
diff --git a/llvm/include/llvm/CodeGen/LiveRegUnits.h b/llvm/include/llvm/CodeGen/LiveRegUnits.h
index e96165d6b3bbf..405a9c123d041 100644
--- a/llvm/include/llvm/CodeGen/LiveRegUnits.h
+++ b/llvm/include/llvm/CodeGen/LiveRegUnits.h
@@ -43,7 +43,7 @@ class LiveRegUnits {
/// For a machine instruction \p MI, adds all register units used in
/// \p UsedRegUnits and defined or clobbered in \p ModifiedRegUnits. This is
/// useful when walking over a range of instructions to track registers
- /// used or defined seperately.
+ /// used or defined separately.
static void accumulateUsedDefed(const MachineInstr &MI,
LiveRegUnits &ModifiedRegUnits,
LiveRegUnits &UsedRegUnits,
diff --git a/llvm/include/llvm/CodeGen/MIRFormatter.h b/llvm/include/llvm/CodeGen/MIRFormatter.h
index 42087f549426b..ab2244f255f3b 100644
--- a/llvm/include/llvm/CodeGen/MIRFormatter.h
+++ b/llvm/include/llvm/CodeGen/MIRFormatter.h
@@ -46,7 +46,7 @@ class MIRFormatter {
}
/// Implement target specific parsing of immediate mnemonics. The mnemonic is
- /// dot seperated strings.
+ /// dot separated strings.
virtual bool parseImmMnemonic(const unsigned OpCode, const unsigned OpIdx,
StringRef Src, int64_t &Imm,
ErrorCallbackType ErrorCallback) const {
diff --git a/llvm/include/llvm/MC/MCAsmInfo.h b/llvm/include/llvm/MC/MCAsmInfo.h
index f9dd6012d5e94..48056b6ad6137 100644
--- a/llvm/include/llvm/MC/MCAsmInfo.h
+++ b/llvm/include/llvm/MC/MCAsmInfo.h
@@ -393,7 +393,7 @@ class MCAsmInfo {
/// for ELF targets. Defaults to true.
bool HasSingleParameterDotFile = true;
- /// True if the target has a four strings .file directive, strings seperated
+ /// True if the target has a four strings .file directive, strings separated
/// by comma. Defaults to false.
bool HasFourStringsDotFile = false;
diff --git a/llvm/include/llvm/Support/raw_socket_stream.h b/llvm/include/llvm/Support/raw_socket_stream.h
index bddd47eb75e1a..eed865fb5af49 100644
--- a/llvm/include/llvm/Support/raw_socket_stream.h
+++ b/llvm/include/llvm/Support/raw_socket_stream.h
@@ -61,7 +61,7 @@ class ListeningSocket {
std::atomic<int> FD;
std::string SocketPath; // Not modified after construction
- /// If a seperate thread calls ListeningSocket::shutdown, the ListeningSocket
+ /// If a separate thread calls ListeningSocket::shutdown, the ListeningSocket
/// file descriptor (FD) could be closed while ::poll is waiting for it to be
/// ready to perform a I/O operations. ::poll will continue to block even
/// after FD is closed so use a self-pipe mechanism to get ::poll to return
diff --git a/llvm/lib/CodeGen/AsmPrinter/CodeViewDebug.h b/llvm/lib/CodeGen/AsmPrinter/CodeViewDebug.h
index 4c03bf79d04da..55d149e049c94 100644
--- a/llvm/lib/CodeGen/AsmPrinter/CodeViewDebug.h
+++ b/llvm/lib/CodeGen/AsmPrinter/CodeViewDebug.h
@@ -220,7 +220,7 @@ class LLVM_LIBRARY_VISIBILITY CodeViewDebug : public DebugHandlerBase {
// DIGlobalVariableExpression referencing the DIGlobalVariable.
DenseMap<const DIGlobalVariable *, uint64_t> CVGlobalVariableOffsets;
- // Map used to seperate variables according to the lexical scope they belong
+ // Map used to separate variables according to the lexical scope they belong
// in. This is populated by recordLocalVariable() before
// collectLexicalBlocks() separates the variables between the FunctionInfo
// and LexicalBlocks.
diff --git a/llvm/lib/CodeGen/AssignmentTrackingAnalysis.cpp b/llvm/lib/CodeGen/AssignmentTrackingAnalysis.cpp
index ec5fc06d01fb1..8afd75069589e 100644
--- a/llvm/lib/CodeGen/AssignmentTrackingAnalysis.cpp
+++ b/llvm/lib/CodeGen/AssignmentTrackingAnalysis.cpp
@@ -2493,7 +2493,7 @@ removeRedundantDbgLocsUsingBackwardScan(const BasicBlock *BB,
bool Changed = false;
SmallDenseMap<DebugAggregate, BitVector> VariableDefinedBytes;
// Scan over the entire block, not just over the instructions mapped by
- // FnVarLocs, because wedges in FnVarLocs may only be seperated by debug
+ // FnVarLocs, because wedges in FnVarLocs may only be separated by debug
// instructions.
for (const Instruction &I : reverse(*BB)) {
if (!isa<DbgVariableIntrinsic>(I)) {
@@ -2593,7 +2593,7 @@ removeRedundantDbgLocsUsingForwardScan(const BasicBlock *BB,
VariableMap;
// Scan over the entire block, not just over the instructions mapped by
- // FnVarLocs, because wedges in FnVarLocs may only be seperated by debug
+ // FnVarLocs, because wedges in FnVarLocs may only be separated by debug
// instructions.
for (const Instruction &I : *BB) {
// Get the defs that come just before this instruction.
@@ -2681,7 +2681,7 @@ removeUndefDbgLocsFromEntryBlock(const BasicBlock *BB,
DenseMap<DebugVariable, std::pair<Value *, DIExpression *>> VariableMap;
// Scan over the entire block, not just over the instructions mapped by
- // FnVarLocs, because wedges in FnVarLocs may only be seperated by debug
+ // FnVarLocs, because wedges in FnVarLocs may only be separated by debug
// instructions.
for (const Instruction &I : *BB) {
// Get the defs that come just before this instruction.
diff --git a/llvm/lib/CodeGen/SelectionDAG/SelectionDAGBuilder.cpp b/llvm/lib/CodeGen/SelectionDAG/SelectionDAGBuilder.cpp
index be5e0f6ef058b..58cf7de6fc20d 100644
--- a/llvm/lib/CodeGen/SelectionDAG/SelectionDAGBuilder.cpp
+++ b/llvm/lib/CodeGen/SelectionDAG/SelectionDAGBuilder.cpp
@@ -6606,7 +6606,7 @@ void SelectionDAGBuilder::visitIntrinsicCall(const CallInst &I,
return;
}
case Intrinsic::dbg_assign: {
- // Debug intrinsics are handled seperately in assignment tracking mode.
+ // Debug intrinsics are handled separately in assignment tracking mode.
if (AssignmentTrackingEnabled)
return;
// If assignment tracking hasn't been enabled then fall through and treat
@@ -6614,7 +6614,7 @@ void SelectionDAGBuilder::visitIntrinsicCall(const CallInst &I,
[[fallthrough]];
}
case Intrinsic::dbg_value: {
- // Debug intrinsics are handled seperately in assignment tracking mode.
+ // Debug intrinsics are handled separately in assignment tracking mode.
if (AssignmentTrackingEnabled)
return;
const DbgValueInst &DI = cast<DbgValueInst>(I);
diff --git a/llvm/lib/FileCheck/FileCheck.cpp b/llvm/lib/FileCheck/FileCheck.cpp
index 1719f8ef2b436..1eb8330232321 100644
--- a/llvm/lib/FileCheck/FileCheck.cpp
+++ b/llvm/lib/FileCheck/FileCheck.cpp
@@ -624,7 +624,7 @@ Expected<std::unique_ptr<Expression>> Pattern::parseNumericSubstitutionBlock(
ExpressionFormat ExplicitFormat = ExpressionFormat();
unsigned Precision = 0;
- // Parse format specifier (NOTE: ',' is also an argument seperator).
+ // Parse format specifier (NOTE: ',' is also an argument separator).
size_t FormatSpecEnd = Expr.find(',');
size_t FunctionStart = Expr.find('(');
if (FormatSpecEnd != StringRef::npos && FormatSpecEnd < FunctionStart) {
diff --git a/llvm/lib/IR/DebugInfo.cpp b/llvm/lib/IR/DebugInfo.cpp
index 4c3f37ceaaa46..228e17641ffc4 100644
--- a/llvm/lib/IR/DebugInfo.cpp
+++ b/llvm/lib/IR/DebugInfo.cpp
@@ -2010,7 +2010,7 @@ bool calculateFragmentIntersectImpl(
// SliceSizeInBits=32, Dest=%dest, Assign=dbg.assign)
//
// Drawing the store (s) in memory followed by the shortened version ($),
- // then the dbg.assign (d), with the fragment information on a seperate scale
+ // then the dbg.assign (d), with the fragment information on a separate scale
// underneath:
//
// Memory
diff --git a/llvm/lib/MC/MCPseudoProbe.cpp b/llvm/lib/MC/MCPseudoProbe.cpp
index 040f3aab88128..2a75f46c57aa8 100644
--- a/llvm/lib/MC/MCPseudoProbe.cpp
+++ b/llvm/lib/MC/MCPseudoProbe.cpp
@@ -146,7 +146,7 @@ void MCPseudoProbeInlineTree::emit(MCObjectStreamer *MCOS,
dbgs() << "Group [\n";
MCPseudoProbeTable::DdgPrintIndent += 2;
});
- assert(!isRoot() && "Root should be handled seperately");
+ assert(!isRoot() && "Root should be handled separately");
// Emit probes grouped by GUID.
LLVM_DEBUG({
diff --git a/llvm/lib/Support/VirtualFileSystem.cpp b/llvm/lib/Support/VirtualFileSystem.cpp
index 7360901f2962c..f9c15bf7809eb 100644
--- a/llvm/lib/Support/VirtualFileSystem.cpp
+++ b/llvm/lib/Support/VirtualFileSystem.cpp
@@ -1373,7 +1373,7 @@ std::error_code RedirectingFileSystem::makeAbsolute(SmallVectorImpl<char> &Path)
llvm::sys::path::is_absolute(Path,
llvm::sys::path::Style::windows_backslash))
// This covers windows absolute path with forward slash as well, as the
- // forward slashes are treated as path seperation in llvm::path
+ // forward slashes are treated as path separation in llvm::path
// regardless of what path::Style is used.
return {};
diff --git a/llvm/lib/Support/raw_socket_stream.cpp b/llvm/lib/Support/raw_socket_stream.cpp
index 549d537709bf2..4cd3d58b80198 100644
--- a/llvm/lib/Support/raw_socket_stream.cpp
+++ b/llvm/lib/Support/raw_socket_stream.cpp
@@ -266,7 +266,7 @@ void ListeningSocket::shutdown() {
::close(ObservedFD);
::unlink(SocketPath.c_str());
- // Ensure ::poll returns if shutdown is called by a seperate thread
+ // Ensure ::poll returns if shutdown is called by a separate thread
char Byte = 'A';
ssize_t written = ::write(PipeFD[1], &Byte, 1);
diff --git a/llvm/lib/Target/ARM/ARMISelLowering.cpp b/llvm/lib/Target/ARM/ARMISelLowering.cpp
index e3270471981cc..5a617968307dd 100644
--- a/llvm/lib/Target/ARM/ARMISelLowering.cpp
+++ b/llvm/lib/Target/ARM/ARMISelLowering.cpp
@@ -13709,7 +13709,7 @@ static SDValue PerformADDVecReduce(SDNode *N, SelectionDAG &DAG,
// t2: i64 = build_pair t1, t1:1
// t3: i64 = add t2, y
// Otherwise we try to push the add up above VADDLVAx, to potentially allow
- // the add to be simplified seperately.
+ // the add to be simplified separately.
// We also need to check for sext / zext and commutitive adds.
auto MakeVecReduce = [&](unsigned Opcode, unsigned OpcodeA, SDValue NA,
SDValue NB) {
diff --git a/llvm/lib/Target/RISCV/RISCVMachineFunctionInfo.h b/llvm/lib/Target/RISCV/RISCVMachineFunctionInfo.h
index fcc20c17c6b40..779c652b4d8fc 100644
--- a/llvm/lib/Target/RISCV/RISCVMachineFunctionInfo.h
+++ b/llvm/lib/Target/RISCV/RISCVMachineFunctionInfo.h
@@ -135,7 +135,7 @@ class RISCVMachineFunctionInfo : public MachineFunctionInfo {
bool isPushable(const MachineFunction &MF) const {
// We cannot use fixed locations for the callee saved spill slots if the
// function uses a varargs save area.
- // TODO: Use a seperate placement for vararg registers to enable Zcmp.
+ // TODO: Use a separate placement for vararg registers to enable Zcmp.
return MF.getSubtarget<RISCVSubtarget>().hasStdExtZcmp() &&
!MF.getTarget().Options.DisableFramePointerElim(MF) &&
VarArgsSaveSize == 0;
diff --git a/llvm/lib/TargetParser/RISCVISAInfo.cpp b/llvm/lib/TargetParser/RISCVISAInfo.cpp
index 4e0d07d39f9ba..258238bfb212d 100644
--- a/llvm/lib/TargetParser/RISCVISAInfo.cpp
+++ b/llvm/lib/TargetParser/RISCVISAInfo.cpp
@@ -757,7 +757,7 @@ RISCVISAInfo::parseArchString(StringRef Arch, bool EnableExperimentalExtension,
Ext, SeenExtMap, IgnoreUnknown, EnableExperimentalExtension,
ExperimentalExtensionVersionCheck))
return std::move(E);
- // Multi-letter extension must be seperate following extension with
+ // Multi-letter extension must be separate following extension with
// underscore
break;
} else {
diff --git a/llvm/lib/TextAPI/Utils.cpp b/llvm/lib/TextAPI/Utils.cpp
index 01021e3a264dd..8a06d53942a94 100644
--- a/llvm/lib/TextAPI/Utils.cpp
+++ b/llvm/lib/TextAPI/Utils.cpp
@@ -215,7 +215,7 @@ llvm::MachO::parseAliasList(std::unique_ptr<llvm::MemoryBuffer> &Buffer) {
if (L.starts_with("#"))
continue;
StringRef Symbol, Remain, Alias;
- // Base symbol is seperated by whitespace.
+ // Base symbol is separated by whitespace.
std::tie(Symbol, Remain) = getToken(L);
// The Alias symbol ends before a comment or EOL.
std::tie(Alias, Remain) = getToken(Remain, "#");
diff --git a/llvm/lib/Transforms/IPO/Attributor.cpp b/llvm/lib/Transforms/IPO/Attributor.cpp
index b6866580ccd3f..09d7ee7c9478d 100644
--- a/llvm/lib/Transforms/IPO/Attributor.cpp
+++ b/llvm/lib/Transforms/IPO/Attributor.cpp
@@ -132,13 +132,13 @@ static cl::opt<bool>
#ifndef NDEBUG
static cl::list<std::string>
SeedAllowList("attributor-seed-allow-list", cl::Hidden,
- cl::desc("Comma seperated list of attribute names that are "
+ cl::desc("Comma separated list of attribute names that are "
"allowed to be seeded."),
cl::CommaSeparated);
static cl::list<std::string> FunctionSeedAllowList(
"attributor-function-seed-allow-list", cl::Hidden,
- cl::desc("Comma seperated list of function names that are "
+ cl::desc("Comma separated list of function names that are "
"allowed to be seeded."),
cl::CommaSeparated);
#endif
diff --git a/llvm/lib/Transforms/IPO/SampleProfileProbe.cpp b/llvm/lib/Transforms/IPO/SampleProfileProbe.cpp
index 3daa05a76d364..882b15c23ede5 100644
--- a/llvm/lib/Transforms/IPO/SampleProfileProbe.cpp
+++ b/llvm/lib/Transforms/IPO/SampleProfileProbe.cpp
@@ -343,7 +343,7 @@ uint32_t SampleProfileProber::getCallsiteId(const Instruction *Call) const {
void SampleProfileProber::instrumentOneFunc(Function &F, TargetMachine *TM) {
Module *M = F.getParent();
MDBuilder MDB(F.getContext());
- // Since the GUID from probe desc and inline stack are computed seperately, we
+ // Since the GUID from probe desc and inline stack are computed separately, we
// need to make sure their names are consistent, so here also use the name
// from debug info.
StringRef FName = F.getName();
diff --git a/llvm/lib/Transforms/Scalar/RewriteStatepointsForGC.cpp b/llvm/lib/Transforms/Scalar/RewriteStatepointsForGC.cpp
index 858e54c4a9bc2..10fc4050966bd 100644
--- a/llvm/lib/Transforms/Scalar/RewriteStatepointsForGC.cpp
+++ b/llvm/lib/Transforms/Scalar/RewriteStatepointsForGC.cpp
@@ -1323,7 +1323,7 @@ static void findBasePointers(DominatorTree &DT, DefiningValueMapTy &DVCache,
IsKnownBaseMapTy &KnownBases) {
StatepointLiveSetTy PotentiallyDerivedPointers = result.LiveSet;
// We assume that all pointers passed to deopt are base pointers; as an
- // optimization, we can use this to avoid seperately materializing the base
+ // optimization, we can use this to avoid separately materializing the base
// pointer graph. This is only relevant since we're very conservative about
// generating new conflict nodes during base pointer insertion. If we were
// smarter there, this would be irrelevant.
diff --git a/llvm/lib/Transforms/Utils/LoopUnrollRuntime.cpp b/llvm/lib/Transforms/Utils/LoopUnrollRuntime.cpp
index dd7150bc63ec4..15303a17467b4 100644
--- a/llvm/lib/Transforms/Utils/LoopUnrollRuntime.cpp
+++ b/llvm/lib/Transforms/Utils/LoopUnrollRuntime.cpp
@@ -849,7 +849,7 @@ bool llvm::UnrollRuntimeLoopRemainder(
for (unsigned i = 0; i < oldNumOperands; i++){
auto *PredBB =PN.getIncomingBlock(i);
if (PredBB == Latch)
- // The latch exit is handled seperately, see connectX
+ // The latch exit is handled separately, see connectX
continue;
if (!L->contains(PredBB))
// Even if we had dedicated exits, the code above inserted an
diff --git a/llvm/test/CodeGen/X86/AMX/amx-greedy-ra.ll b/llvm/test/CodeGen/X86/AMX/amx-greedy-ra.ll
index 2ca0e3e37107f..8f314fe2a843b 100644
--- a/llvm/test/CodeGen/X86/AMX/amx-greedy-ra.ll
+++ b/llvm/test/CodeGen/X86/AMX/amx-greedy-ra.ll
@@ -1,7 +1,7 @@
; NOTE: Assertions have been autogenerated by utils/update_mir_test_checks.py
; RUN: llc < %s -mtriple=x86_64-unknown-unknown -mattr=+amx-int8 -mattr=+avx512f -verify-machineinstrs -stop-after tileconfig | FileCheck %s
-; Test the tile register is allocated in a seperate pass.
+; Test the tile register is allocated in a separate pass.
define i16 @foo(i32 noundef %t, i16 %row, i16 %col) nounwind {
; CHECK-LABEL: name: foo
diff --git a/llvm/test/CodeGen/X86/apx/shift-eflags.ll b/llvm/test/CodeGen/X86/apx/shift-eflags.ll
index 932cdc189bf9f..5da5090307e62 100644
--- a/llvm/test/CodeGen/X86/apx/shift-eflags.ll
+++ b/llvm/test/CodeGen/X86/apx/shift-eflags.ll
@@ -159,7 +159,7 @@ define i32 @shl_const1_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; ashr by variable - use seperate test
+; ashr by variable - use separate test
define i32 @ashr_var(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: ashr_var:
; CHECK: # %bb.0:
@@ -176,7 +176,7 @@ define i32 @ashr_var(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; lshr by variable - use seperate test
+; lshr by variable - use separate test
define i32 @lshr_var(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: lshr_var:
; CHECK: # %bb.0:
@@ -193,7 +193,7 @@ define i32 @lshr_var(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; shl by variable - use seperate test
+; shl by variable - use separate test
define i32 @shl_var(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: shl_var:
; CHECK: # %bb.0:
@@ -210,7 +210,7 @@ define i32 @shl_var(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; ashr by variable and using result - use seperate test
+; ashr by variable and using result - use separate test
define i32 @ashr_var_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: ashr_var_self_select:
; CHECK: # %bb.0:
@@ -226,7 +226,7 @@ define i32 @ashr_var_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; lshr by variable and using result - use seperate test
+; lshr by variable and using result - use separate test
define i32 @lshr_var_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: lshr_var_self_select:
; CHECK: # %bb.0:
@@ -242,7 +242,7 @@ define i32 @lshr_var_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; shl by variable and using result - use seperate test
+; shl by variable and using result - use separate test
define i32 @shl_var_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: shl_var_self_select:
; CHECK: # %bb.0:
@@ -258,7 +258,7 @@ define i32 @shl_var_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; ashr by non-zero variable - use seperate test
+; ashr by non-zero variable - use separate test
define i32 @ashr_var_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: ashr_var_amt_never_zero:
; CHECK: # %bb.0:
@@ -275,7 +275,7 @@ define i32 @ashr_var_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; lshr by non-zero variable - use seperate test
+; lshr by non-zero variable - use separate test
define i32 @lshr_var_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: lshr_var_amt_never_zero:
; CHECK: # %bb.0:
@@ -292,7 +292,7 @@ define i32 @lshr_var_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; shl by non-zero variable - use seperate test
+; shl by non-zero variable - use separate test
define i32 @shl_var_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: shl_var_amt_never_zero:
; CHECK: # %bb.0:
@@ -309,7 +309,7 @@ define i32 @shl_var_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; ashr by non-zero variable and using result - use seperate test
+; ashr by non-zero variable and using result - use separate test
define i32 @ashr_var_self_select_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: ashr_var_self_select_amt_never_zero:
; CHECK: # %bb.0:
@@ -325,7 +325,7 @@ define i32 @ashr_var_self_select_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %
ret i32 %r
}
-; lshr by non-zero variable and using result - use seperate test
+; lshr by non-zero variable and using result - use separate test
define i32 @lshr_var_self_select_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: lshr_var_self_select_amt_never_zero:
; CHECK: # %bb.0:
@@ -341,7 +341,7 @@ define i32 @lshr_var_self_select_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %
ret i32 %r
}
-; shl by non-zero variable and using result - use seperate test
+; shl by non-zero variable and using result - use separate test
define i32 @shl_var_self_select_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: shl_var_self_select_amt_never_zero:
; CHECK: # %bb.0:
diff --git a/llvm/test/CodeGen/X86/merge-consecutive-stores-nt.ll b/llvm/test/CodeGen/X86/merge-consecutive-stores-nt.ll
index c08056982bd83..9c3057e4e42a4 100644
--- a/llvm/test/CodeGen/X86/merge-consecutive-stores-nt.ll
+++ b/llvm/test/CodeGen/X86/merge-consecutive-stores-nt.ll
@@ -158,7 +158,7 @@ define void @merge_2_v4f32_align32_mix_ntstore(ptr %a0, ptr %a1) nounwind {
}
; AVX2 can't perform NT-load-ymm on 16-byte aligned memory.
-; Must be kept seperate as VMOVNTDQA xmm.
+; Must be kept separate as VMOVNTDQA xmm.
define void @merge_2_v4f32_align16_ntload(ptr %a0, ptr %a1) nounwind {
; X86-LABEL: merge_2_v4f32_align16_ntload:
; X86: # %bb.0:
@@ -211,7 +211,7 @@ define void @merge_2_v4f32_align16_ntload(ptr %a0, ptr %a1) nounwind {
}
; AVX can't perform NT-store-ymm on 16-byte aligned memory.
-; Must be kept seperate as VMOVNTPS xmm.
+; Must be kept separate as VMOVNTPS xmm.
define void @merge_2_v4f32_align16_ntstore(ptr %a0, ptr %a1) nounwind {
; X86-LABEL: merge_2_v4f32_align16_ntstore:
; X86: # %bb.0:
diff --git a/llvm/test/CodeGen/X86/shift-eflags.ll b/llvm/test/CodeGen/X86/shift-eflags.ll
index 8d4597ec21bcd..6eddf50ce5c9d 100644
--- a/llvm/test/CodeGen/X86/shift-eflags.ll
+++ b/llvm/test/CodeGen/X86/shift-eflags.ll
@@ -171,7 +171,7 @@ define i32 @shl_const1_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; ashr by variable - use seperate test
+; ashr by variable - use separate test
define i32 @ashr_var(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: ashr_var:
; CHECK: # %bb.0:
@@ -188,7 +188,7 @@ define i32 @ashr_var(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; lshr by variable - use seperate test
+; lshr by variable - use separate test
define i32 @lshr_var(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: lshr_var:
; CHECK: # %bb.0:
@@ -205,7 +205,7 @@ define i32 @lshr_var(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; shl by variable - use seperate test
+; shl by variable - use separate test
define i32 @shl_var(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: shl_var:
; CHECK: # %bb.0:
@@ -222,7 +222,7 @@ define i32 @shl_var(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; ashr by variable and using result - use seperate test
+; ashr by variable and using result - use separate test
define i32 @ashr_var_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: ashr_var_self_select:
; CHECK: # %bb.0:
@@ -239,7 +239,7 @@ define i32 @ashr_var_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; lshr by variable and using result - use seperate test
+; lshr by variable and using result - use separate test
define i32 @lshr_var_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: lshr_var_self_select:
; CHECK: # %bb.0:
@@ -256,7 +256,7 @@ define i32 @lshr_var_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; shl by variable and using result - use seperate test
+; shl by variable and using result - use separate test
define i32 @shl_var_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: shl_var_self_select:
; CHECK: # %bb.0:
@@ -273,7 +273,7 @@ define i32 @shl_var_self_select(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; ashr by non-zero variable - use seperate test
+; ashr by non-zero variable - use separate test
define i32 @ashr_var_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: ashr_var_amt_never_zero:
; CHECK: # %bb.0:
@@ -292,7 +292,7 @@ define i32 @ashr_var_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; lshr by non-zero variable - use seperate test
+; lshr by non-zero variable - use separate test
define i32 @lshr_var_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: lshr_var_amt_never_zero:
; CHECK: # %bb.0:
@@ -311,7 +311,7 @@ define i32 @lshr_var_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; shl by non-zero variable - use seperate test
+; shl by non-zero variable - use separate test
define i32 @shl_var_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: shl_var_amt_never_zero:
; CHECK: # %bb.0:
@@ -330,7 +330,7 @@ define i32 @shl_var_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
ret i32 %r
}
-; ashr by non-zero variable and using result - use seperate test
+; ashr by non-zero variable and using result - use separate test
define i32 @ashr_var_self_select_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: ashr_var_self_select_amt_never_zero:
; CHECK: # %bb.0:
@@ -349,7 +349,7 @@ define i32 @ashr_var_self_select_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %
ret i32 %r
}
-; lshr by non-zero variable and using result - use seperate test
+; lshr by non-zero variable and using result - use separate test
define i32 @lshr_var_self_select_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: lshr_var_self_select_amt_never_zero:
; CHECK: # %bb.0:
@@ -368,7 +368,7 @@ define i32 @lshr_var_self_select_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %
ret i32 %r
}
-; shl by non-zero variable and using result - use seperate test
+; shl by non-zero variable and using result - use separate test
define i32 @shl_var_self_select_amt_never_zero(i32 %a0, i32 %a1, i32 %a2, i32 %a3) {
; CHECK-LABEL: shl_var_self_select_amt_never_zero:
; CHECK: # %bb.0:
diff --git a/llvm/test/Transforms/InstSimplify/constant-fold-fp-denormal.ll b/llvm/test/Transforms/InstSimplify/constant-fold-fp-denormal.ll
index e3ff9416abdd1..bcd75898a4ffd 100644
--- a/llvm/test/Transforms/InstSimplify/constant-fold-fp-denormal.ll
+++ b/llvm/test/Transforms/InstSimplify/constant-fold-fp-denormal.ll
@@ -2,7 +2,7 @@
; RUN: opt -S -passes=instsimplify < %s | FileCheck %s
; Test cases for denormal handling mode when constant folding floating point
-; operations. Input and output modes are checked seperately.
+; operations. Input and output modes are checked separately.
; ============================================================================ ;
; fadd tests
diff --git a/llvm/test/Transforms/LoopVectorize/LoongArch/defaults.ll b/llvm/test/Transforms/LoopVectorize/LoongArch/defaults.ll
index 28c1eef84e257..2cee1dacea37d 100644
--- a/llvm/test/Transforms/LoopVectorize/LoongArch/defaults.ll
+++ b/llvm/test/Transforms/LoopVectorize/LoongArch/defaults.ll
@@ -4,7 +4,7 @@
;; This is a collection of tests whose only purpose is to show changes in the
;; default configuration. Please keep these tests minimal - if you're testing
;; functionality of some specific configuration, please place that in a
-;; seperate test file with a hard coded configuration (even if that
+;; separate test file with a hard coded configuration (even if that
;; configuration is the current default).
target datalayout = "e-m:e-p:64:64-i64:64-i128:128-n64-S128"
diff --git a/llvm/test/Transforms/LoopVectorize/RISCV/defaults.ll b/llvm/test/Transforms/LoopVectorize/RISCV/defaults.ll
index db0be4c628157..1d1b20d16d090 100644
--- a/llvm/test/Transforms/LoopVectorize/RISCV/defaults.ll
+++ b/llvm/test/Transforms/LoopVectorize/RISCV/defaults.ll
@@ -4,7 +4,7 @@
; This is a collection of tests whose only purpose is to show changes in the
; default configuration. Please keep these tests minimal - if you're testing
; functionality of some specific configuration, please place that in a
-; seperate test file with a hard coded configuration (even if that
+; separate test file with a hard coded configuration (even if that
; configuration is the current default).
target datalayout = "e-m:e-p:64:64-i64:64-i128:128-n64-S128"
diff --git a/llvm/test/Transforms/SeparateConstOffsetFromGEP/split-gep-or-as-add.ll b/llvm/test/Transforms/SeparateConstOffsetFromGEP/split-gep-or-as-add.ll
index e405bbd5347ee..b3096820425b8 100644
--- a/llvm/test/Transforms/SeparateConstOffsetFromGEP/split-gep-or-as-add.ll
+++ b/llvm/test/Transforms/SeparateConstOffsetFromGEP/split-gep-or-as-add.ll
@@ -3,7 +3,7 @@
;; Check that or operations, either with operands with no bits in common or that
;; are disjoint are lowered into constant GEPs. Note that because this is a
-;; target-independent test, the GEP seperator will lower the seperated-off constant
+;; target-independent test, the GEP separator will lower the separated-off constant
;; part to ptrtoint-based arithmetic.
define void @testOrDoesntSplit(ptr %p) {
diff --git a/llvm/test/Verifier/alloc-size-failedparse.ll b/llvm/test/Verifier/alloc-size-failedparse.ll
index ec492269d2ef5..64e3b162ed9b7 100644
--- a/llvm/test/Verifier/alloc-size-failedparse.ll
+++ b/llvm/test/Verifier/alloc-size-failedparse.ll
@@ -1,7 +1,7 @@
; RUN: not llvm-as %s -o /dev/null 2>&1 | FileCheck %s
;
; We handle allocsize with identical args in the parser, rather than the
-; verifier. So, a seperate test is needed.
+; verifier. So, a separate test is needed.
; CHECK: 'allocsize' indices can't refer to the same parameter
declare ptr @a(i32, i32) allocsize(0, 0)
diff --git a/llvm/test/tools/llvm-ar/windows-path.test b/llvm/test/tools/llvm-ar/windows-path.test
index e33fbf532c338..9c5cf1319553b 100644
--- a/llvm/test/tools/llvm-ar/windows-path.test
+++ b/llvm/test/tools/llvm-ar/windows-path.test
@@ -1,4 +1,4 @@
-# Test that windows path seperators are handled correctly.
+# Test that windows path separators are handled correctly.
REQUIRES: system-windows
# Note: many of these tests depend on relative paths, so we have to cd to a
diff --git a/llvm/test/tools/llvm-objcopy/ELF/mirror-permissions-win.test b/llvm/test/tools/llvm-objcopy/ELF/mirror-permissions-win.test
index c35df343c0d32..f8b0d389df9b8 100644
--- a/llvm/test/tools/llvm-objcopy/ELF/mirror-permissions-win.test
+++ b/llvm/test/tools/llvm-objcopy/ELF/mirror-permissions-win.test
@@ -1,7 +1,7 @@
## Test that permissions for ouput files are mirrored
## from their input files.
-## The Unix version of this test is seperated because it needs
+## The Unix version of this test is separated because it needs
## to use umask(1). Windows has no umask, so it can be considered
## to be always 0, the required behavior.
# REQUIRES: system-windows
diff --git a/llvm/tools/llvm-cov/CodeCoverage.cpp b/llvm/tools/llvm-cov/CodeCoverage.cpp
index 1e5bfbe5c3aad..75028ac0bb505 100644
--- a/llvm/tools/llvm-cov/CodeCoverage.cpp
+++ b/llvm/tools/llvm-cov/CodeCoverage.cpp
@@ -515,7 +515,7 @@ void CodeCoverageTool::remapPathNames(const CoverageMapping &Coverage) {
if (!PathRemappings)
return;
- // Convert remapping paths to native paths with trailing seperators.
+ // Convert remapping paths to native paths with trailing separators.
auto nativeWithTrailing = [](StringRef Path) -> std::string {
if (Path.empty())
return "";
diff --git a/llvm/tools/llvm-profgen/PerfReader.cpp b/llvm/tools/llvm-profgen/PerfReader.cpp
index e1f5cc900cfd7..111c546f5329f 100644
--- a/llvm/tools/llvm-profgen/PerfReader.cpp
+++ b/llvm/tools/llvm-profgen/PerfReader.cpp
@@ -564,7 +564,7 @@ bool PerfScriptReader::extractLBRStack(TraceStream &TraceIt,
// The raw format of LBR stack is like:
// 0x4005c8/0x4005dc/P/-/-/0 0x40062f/0x4005b0/P/-/-/0 ...
// ... 0x4005c8/0x4005dc/P/-/-/0
- // It's in FIFO order and seperated by whitespace.
+ // It's in FIFO order and separated by whitespace.
SmallVector<StringRef, 32> Records;
TraceIt.getCurrentLine().rtrim().split(Records, " ", -1, false);
auto WarnInvalidLBR = [](TraceStream &TraceIt) {
diff --git a/llvm/unittests/Support/Path.cpp b/llvm/unittests/Support/Path.cpp
index bdae7a8ee4b55..463a6991dac51 100644
--- a/llvm/unittests/Support/Path.cpp
+++ b/llvm/unittests/Support/Path.cpp
@@ -626,8 +626,8 @@ TEST(SupportDeathTest, TempDirectoryOnWindows) {
//
diff erent values of specific env vars. To prevent corrupting env vars of
// the current process all checks are done in separated processes.
EXPECT_TEMP_DIR(_wputenv_s(L"TMP", L"C:\\OtherFolder"), "C:\\OtherFolder");
- EXPECT_TEMP_DIR(_wputenv_s(L"TMP", L"C:/Unix/Path/Seperators"),
- "C:\\Unix\\Path\\Seperators");
+ EXPECT_TEMP_DIR(_wputenv_s(L"TMP", L"C:/Unix/Path/Separators"),
+ "C:\\Unix\\Path\\Separators");
EXPECT_TEMP_DIR(_wputenv_s(L"TMP", L"Local Path"), ".+\\Local Path$");
EXPECT_TEMP_DIR(_wputenv_s(L"TMP", L"F:\\TrailingSep\\"), "F:\\TrailingSep");
EXPECT_TEMP_DIR(
diff --git a/mlir/include/mlir/Analysis/Presburger/IntegerRelation.h b/mlir/include/mlir/Analysis/Presburger/IntegerRelation.h
index 40e96e2583d22..ad26e9786d0b0 100644
--- a/mlir/include/mlir/Analysis/Presburger/IntegerRelation.h
+++ b/mlir/include/mlir/Analysis/Presburger/IntegerRelation.h
@@ -642,7 +642,7 @@ class IntegerRelation {
/// the split become symbols, or some of the symbols immediately after the
/// split become dimensions.
void setDimSymbolSeparation(unsigned newSymbolCount) {
- space.setVarSymbolSeperation(newSymbolCount);
+ space.setVarSymbolSeparation(newSymbolCount);
}
/// Return a set corresponding to all points in the domain of the relation.
diff --git a/mlir/include/mlir/Analysis/Presburger/PresburgerSpace.h b/mlir/include/mlir/Analysis/Presburger/PresburgerSpace.h
index a8ec373f885e2..9a41e4aee61d0 100644
--- a/mlir/include/mlir/Analysis/Presburger/PresburgerSpace.h
+++ b/mlir/include/mlir/Analysis/Presburger/PresburgerSpace.h
@@ -236,7 +236,7 @@ class PresburgerSpace {
/// symbol count, either a chunk of dimensional variables immediately before
/// the split become symbols, or some of the symbols immediately after the
/// split become dimensions.
- void setVarSymbolSeperation(unsigned newSymbolCount);
+ void setVarSymbolSeparation(unsigned newSymbolCount);
/// Swaps the posA^th variable of kindA and posB^th variable of kindB.
void swapVar(VarKind kindA, VarKind kindB, unsigned posA, unsigned posB);
diff --git a/mlir/include/mlir/Dialect/OpenMP/OpenMPInterfaces.h b/mlir/include/mlir/Dialect/OpenMP/OpenMPInterfaces.h
index 787c48b05c5c5..989ab1710c211 100644
--- a/mlir/include/mlir/Dialect/OpenMP/OpenMPInterfaces.h
+++ b/mlir/include/mlir/Dialect/OpenMP/OpenMPInterfaces.h
@@ -28,7 +28,7 @@
namespace mlir::omp {
// You can override defaults here or implement more complex implementations of
-// functions. Or define a completely seperate external model implementation,
+// functions. Or define a completely separate external model implementation,
// to override the existing implementation.
struct OffloadModuleDefaultModel
: public OffloadModuleInterface::ExternalModel<OffloadModuleDefaultModel,
diff --git a/mlir/lib/Analysis/Presburger/PresburgerSpace.cpp b/mlir/lib/Analysis/Presburger/PresburgerSpace.cpp
index f00796833482e..e3abbdfeb3f3b 100644
--- a/mlir/lib/Analysis/Presburger/PresburgerSpace.cpp
+++ b/mlir/lib/Analysis/Presburger/PresburgerSpace.cpp
@@ -286,7 +286,7 @@ bool PresburgerSpace::isAligned(const PresburgerSpace &other,
return getNumVarKind(kind) == other.getNumVarKind(kind);
}
-void PresburgerSpace::setVarSymbolSeperation(unsigned newSymbolCount) {
+void PresburgerSpace::setVarSymbolSeparation(unsigned newSymbolCount) {
assert(newSymbolCount <= getNumDimAndSymbolVars() &&
"invalid separation position");
numRange = numRange + numSymbols - newSymbolCount;
diff --git a/mlir/lib/Conversion/GPUCommon/GPUOpsLowering.h b/mlir/lib/Conversion/GPUCommon/GPUOpsLowering.h
index 471a688e85463..0ec260b7dde2a 100644
--- a/mlir/lib/Conversion/GPUCommon/GPUOpsLowering.h
+++ b/mlir/lib/Conversion/GPUCommon/GPUOpsLowering.h
@@ -79,7 +79,7 @@ struct GPUPrintfOpToHIPLowering : public ConvertOpToLLVMPattern<gpu::PrintfOp> {
/// The lowering of gpu.printf to a call to an external printf() function
///
/// This pass will add a declaration of printf() to the GPUModule if needed
-/// and seperate out the format strings into global constants. For some
+/// and separate out the format strings into global constants. For some
/// runtimes, such as OpenCL on AMD, this is sufficient setup, as the compiler
/// will lower printf calls to appropriate device-side code
struct GPUPrintfOpToLLVMCallLowering
diff --git a/mlir/lib/Dialect/LLVMIR/IR/BasicPtxBuilderInterface.cpp b/mlir/lib/Dialect/LLVMIR/IR/BasicPtxBuilderInterface.cpp
index f7f1e944d637d..3dacc70838e3e 100644
--- a/mlir/lib/Dialect/LLVMIR/IR/BasicPtxBuilderInterface.cpp
+++ b/mlir/lib/Dialect/LLVMIR/IR/BasicPtxBuilderInterface.cpp
@@ -65,7 +65,7 @@ void PtxBuilder::insertValue(Value v, PTXRegisterMod itype) {
auto getModifier = [&]() -> const char * {
if (itype == PTXRegisterMod::ReadWrite) {
assert(false && "Read-Write modifier is not supported. Try setting the "
- "same value as Write and Read seperately.");
+ "same value as Write and Read separately.");
return "+";
}
if (itype == PTXRegisterMod::Write) {
diff --git a/mlir/lib/Target/LLVMIR/Dialect/OpenMP/OpenMPToLLVMIRTranslation.cpp b/mlir/lib/Target/LLVMIR/Dialect/OpenMP/OpenMPToLLVMIRTranslation.cpp
index 6ec4c120c11ea..b7b2f8c4fa8c4 100644
--- a/mlir/lib/Target/LLVMIR/Dialect/OpenMP/OpenMPToLLVMIRTranslation.cpp
+++ b/mlir/lib/Target/LLVMIR/Dialect/OpenMP/OpenMPToLLVMIRTranslation.cpp
@@ -2263,7 +2263,7 @@ static llvm::omp::OpenMPOffloadMappingFlags mapParentWithMembers(
// This creates the initial MEMBER_OF mapping that consists of
// the parent/top level container (same as above effectively, except
- // with a fixed initial compile time size and seperate maptype which
+ // with a fixed initial compile time size and separate maptype which
// indicates the true mape type (tofrom etc.). This parent mapping is
// only relevant if the structure in its totality is being mapped,
// otherwise the above suffices.
@@ -2388,7 +2388,7 @@ static void processMapWithMembersOf(
// If we have a partial map (no parent referenced in the map clauses of the
// directive, only members) and only a single member, we do not need to bind
- // the map of the member to the parent, we can pass the member seperately.
+ // the map of the member to the parent, we can pass the member separately.
if (parentClause.getMembers().size() == 1 && parentClause.getPartialMap()) {
auto memberClause = llvm::cast<mlir::omp::MapInfoOp>(
parentClause.getMembers()[0].getDefiningOp());
@@ -2425,7 +2425,7 @@ createAlteredByCaptureMap(MapInfoData &mapData,
LLVM::ModuleTranslation &moduleTranslation,
llvm::IRBuilderBase &builder) {
for (size_t i = 0; i < mapData.MapClause.size(); ++i) {
- // if it's declare target, skip it, it's handled seperately.
+ // if it's declare target, skip it, it's handled separately.
if (!mapData.IsDeclareTarget[i]) {
auto mapOp =
mlir::dyn_cast_if_present<mlir::omp::MapInfoOp>(mapData.MapClause[i]);
diff --git a/mlir/test/Integration/Dialect/SparseTensor/CPU/sparse_reduce_custom_prod.mlir b/mlir/test/Integration/Dialect/SparseTensor/CPU/sparse_reduce_custom_prod.mlir
index d32a92e337ba7..8cbe8fd1ed695 100644
--- a/mlir/test/Integration/Dialect/SparseTensor/CPU/sparse_reduce_custom_prod.mlir
+++ b/mlir/test/Integration/Dialect/SparseTensor/CPU/sparse_reduce_custom_prod.mlir
@@ -27,7 +27,7 @@
// REDEFINE: %{sparsifier_opts} = enable-runtime-library=false enable-buffer-initialization=true vl=2 reassociate-fp-reductions=true enable-index-optimizations=true
// RUN: %{compile} | %{run} | FileCheck %s
-// Product reductions - kept in a seperate file as these are not supported by
+// Product reductions - kept in a separate file as these are not supported by
// the AArch64 SVE backend (so the set-up is a bit
diff erent to
// sparse_reducitons.mlir)
diff --git a/mlir/test/Target/LLVMIR/omptarget-constant-alloca-raise.mlir b/mlir/test/Target/LLVMIR/omptarget-constant-alloca-raise.mlir
index 7a785301eb16b..aa4ac111a8a50 100644
--- a/mlir/test/Target/LLVMIR/omptarget-constant-alloca-raise.mlir
+++ b/mlir/test/Target/LLVMIR/omptarget-constant-alloca-raise.mlir
@@ -5,7 +5,7 @@
// compiler. Certain LLVM IR optimisation passes will perform runtime breaking
// transformations on allocations not found to be in the entry block, current
// OpenMP dialect lowering of TargetOp's will inject user allocations after
-// compiler generated entry code, in a seperate block, this test checks that
+// compiler generated entry code, in a separate block, this test checks that
// a small function which attempts to raise some of these (specifically
// constant sized) allocations performs its task reasonably in these
// scenarios.
diff --git a/openmp/tools/Modules/FindOpenMPTarget.cmake b/openmp/tools/Modules/FindOpenMPTarget.cmake
index 424294090d5d0..d478e3dfff110 100644
--- a/openmp/tools/Modules/FindOpenMPTarget.cmake
+++ b/openmp/tools/Modules/FindOpenMPTarget.cmake
@@ -200,7 +200,7 @@ function(_OPENMP_TARGET_DEVICE_GET_FLAGS LANG DEVICE OPENMP_FLAG_VAR OPENMP_LIB_
file(APPEND ${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/CMakeOutput.log
"Compilation successful, adding flags for ${DEVICE}.\n\n")
- # Clang has a seperate library for target offloading.
+ # Clang has a separate library for target offloading.
if(CMAKE_${LANG}_COMPILER_ID STREQUAL "Clang")
find_library(OpenMPTarget_libomptarget_LIBRARY
NAMES omptarget
More information about the cfe-commits
mailing list
diff --git a/clang-tools-extra/clangd/TidyProvider.cpp b/clang-tools-extra/clangd/TidyProvider.cpp
index a4121df30d3df..a87238e0c0938 100644
--- a/clang-tools-extra/clangd/TidyProvider.cpp
+++ b/clang-tools-extra/clangd/TidyProvider.cpp
@@ -195,10 +195,10 @@ TidyProvider addTidyChecks(llvm::StringRef Checks,
}
TidyProvider disableUnusableChecks(llvm::ArrayRef<std::string> ExtraBadChecks) {
- constexpr llvm::StringLiteral Seperator(",");
+ constexpr llvm::StringLiteral Separator(",");
static const std::string BadChecks = llvm::join_items(
- Seperator,
- // We want this list to start with a seperator to
+ Separator,
+ // We want this list to start with a separator to
// simplify appending in the lambda. So including an
// empty string here will force that.
"",
@@ -227,7 +227,7 @@ TidyProvider disableUnusableChecks(llvm::ArrayRef<std::string> ExtraBadChecks) {
for (const std::string &Str : ExtraBadChecks) {
if (Str.empty())
continue;
- Size += Seperator.size();
+ Size += Separator.size();
if (LLVM_LIKELY(Str.front() != '-'))
++Size;
Size += Str.size();
@@ -238,7 +238,7 @@ TidyProvider disableUnusableChecks(llvm::ArrayRef<std::string> ExtraBadChecks) {
for (const std::string &Str : ExtraBadChecks) {
if (Str.empty())
continue;
- DisableGlob += Seperator;
+ DisableGlob += Separator;
if (LLVM_LIKELY(Str.front() != '-'))
DisableGlob.push_back('-');
DisableGlob += Str;